# PODNAME: Shared::Examples::Net::Amazon::S3::Fixture::response::bucket_objects_list_v1_with_filter_truncated
# ABSTRACT: Shared::Examples providing response fixture

use strict;
use warnings;

use Shared::Examples::Net::Amazon::S3::Fixture;

Shared::Examples::Net::Amazon::S3::Fixture::fixture content => <<'XML';
<?xml version="1.0" encoding="UTF-8"?>
<ListBucketResult xmlns="http://s3.amazonaws.com/doc/2006-03-01/">
	<Name>some-bucket</Name>
	<Prefix>N</Prefix>
	<Marker>Ned</Marker>
	<MaxKeys>40</MaxKeys>
	<IsTruncated>true</IsTruncated>
	<Contents>
		<Key>Nelson</Key>
		<LastModified>2006-01-01T12:00:00.000Z</LastModified>
		<ETag>&quot;828ef3fdfa96f00ad9f27c383fc9ac7f&quot;</ETag>
		<Size>5</Size>
		<StorageClass>STANDARD</StorageClass>
		<Owner>
			<ID>bcaf161ca5fb16fd081034f</ID>
			<DisplayName>webfile</DisplayName>
		</Owner>
	</Contents>
	<Contents>
		<Key>Neo</Key>
		<LastModified>2006-01-01T12:00:00.000Z</LastModified>
		<ETag>&quot;828ef3fdfa96f00ad9f27c383fc9ac7f&quot;</ETag>
		<Size>4</Size>
		<StorageClass>STANDARD</StorageClass>
		<Owner>
			<ID>bcaf1ffd86a5fb16fd081034f</ID>
			<DisplayName>webfile</DisplayName>
		</Owner>
	</Contents>
</ListBucketResult>
XML

__END__

=pod

=encoding UTF-8

=head1 NAME

Shared::Examples::Net::Amazon::S3::Fixture::response::bucket_objects_list_v1_with_filter_truncated - Shared::Examples providing response fixture

=head1 VERSION

version 0.95

=head1 AUTHOR

Branislav Zahradník <barney@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo, Rusty Conover, Branislav Zahradník.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
